import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.BorderFactory;

public class BestTimesDialog extends JDialog implements ActionListener, WindowListener {
  private static final long serialVersionUID = -459646110674871028L;

  private Minesweeper main;

  private JLabel bRecord;
  private JLabel iRecord;
  private JLabel eRecord;
  private JLabel iName;
  private JLabel bName;
  private JLabel eName;

  public BestTimesDialog(Minesweeper main) {
    super(main, "Fastest Mine Sweepers", true);
    this.main = main;
    setLayout(new BorderLayout());
    JPanel panelTop = new JPanel();
    JPanel panelBottom = new JPanel();
    Storage data = this.main.getStorage();
    this.bRecord = new JLabel(data.getRecord(this.main.BEGINNER) + " seconds");
    this.iRecord = new JLabel(data.getRecord(this.main.INTERMEDIATE) + " seconds");
    this.eRecord = new JLabel(data.getRecord(this.main.EXPERT) + " seconds");
    this.bName = new JLabel(data.getName(this.main.BEGINNER));
    this.iName = new JLabel(data.getName(this.main.INTERMEDIATE));
    this.eName = new JLabel(data.getName(this.main.EXPERT));
    panelTop.setBorder(BorderFactory.createEmptyBorder(15, 10, 15, 10));
    panelBottom.setBorder(BorderFactory.createEmptyBorder(0, 10, 15, 10));
    add(panelTop, "North");
    add(panelBottom);
    panelTop.setLayout(new GridBagLayout());
    panelBottom.setLayout(new GridBagLayout());
    GridBagConstraints ct =
        new GridBagConstraints(
            3,
            3,
            1,
            1,
            0.0,
            1.0,
            GridBagConstraints.CENTER,
            GridBagConstraints.NONE,
            new Insets(2, 10, 2, 10),
            0,
            0);
    GridBagConstraints cb =
        new GridBagConstraints(
            2,
            1,
            1,
            1,
            0.0,
            1.0,
            GridBagConstraints.CENTER,
            GridBagConstraints.NONE,
            new Insets(2, 10, 2, 10),
            0,
            0);
    ct.gridx = 0;
    ct.anchor = GridBagConstraints.WEST;
    ct.gridy = 0;
    panelTop.add(new JLabel("Beginner:"), ct);
    ct.gridy = 1;
    panelTop.add(new JLabel("Intermediate:"), ct);
    ct.gridy = 2;
    panelTop.add(new JLabel("Expert:"), ct);
    ct.gridx = 1;
    ct.gridy = GridBagConstraints.RELATIVE;
    ct.weightx = 1.0;
    ct.anchor = GridBagConstraints.CENTER;
    ct.gridy = 0;
    panelTop.add(this.bRecord, ct);
    ct.gridy = 1;
    panelTop.add(this.iRecord, ct);
    ct.gridy = 2;
    panelTop.add(this.eRecord, ct);
    ct.gridx = 2;
    ct.gridy = 0;
    panelTop.add(this.bName, ct);
    ct.gridy = 1;
    panelTop.add(this.iName, ct);
    ct.gridy = 2;
    panelTop.add(this.eName, ct);
    cb.gridx = 0;
    cb.gridy = 0;
    JButton reset = new JButton("Reset Scores");
    panelBottom.add(reset, cb);
    reset.addActionListener(this);
    cb.gridx = 1;
    cb.gridy = 0;
    JButton ok = new JButton("OK");
    panelBottom.add(ok, cb);
    this.getRootPane().setDefaultButton(ok);
    ok.addActionListener(this);
    pack();
    setResizable(false);
    Rectangle screenSize = getGraphicsConfiguration().getBounds();
    setLocation(
        screenSize.x + screenSize.width / 2 - getSize().width / 2,
        screenSize.y + screenSize.height / 2 - getSize().height / 2);
    setVisible(true);
  }

  @Override
  public void actionPerformed(ActionEvent e) {
    String cmd = e.getActionCommand();
    if (cmd.equals("Reset Scores")) {
      Storage data = this.main.getStorage();
      data.setRecord(0, 999);
      data.setRecord(1, 999);
      data.setRecord(2, 999);
      data.setName(0, "Anonymous");
      data.setName(1, "Anonymous");
      data.setName(2, "Anonymous");
      this.bRecord.setText("999 seconds");
      this.iRecord.setText("999 seconds");
      this.eRecord.setText("999 seconds");
      this.bName.setText("Anonymous");
      this.iName.setText("Anonymous");
      this.eName.setText("Anonymous");
      return;
    }
    this.dispose();
  }

  @Override
  public void windowClosing(WindowEvent e) {}

  @Override
  public void windowOpened(WindowEvent e) {}

  @Override
  public void windowClosed(WindowEvent e) {}

  @Override
  public void windowIconified(WindowEvent e) {}

  @Override
  public void windowDeiconified(WindowEvent e) {}

  @Override
  public void windowActivated(WindowEvent e) {}

  @Override
  public void windowDeactivated(WindowEvent e) {}
}
