import java.awt.*;
import javax.swing.*;
import javax.swing.BorderFactory;
import javax.swing.plaf.basic.BasicBorders.ButtonBorder;

public class Board extends JPanel {
  private static final long serialVersionUID = -8979636904753517635L;

  private Minesweeper main;

  private Tile[][] tiles;

  private int height;
  private int width;
  private int numOfMines;

  private void addMines() {
    if (this.numOfMines >= this.width * this.height) {
      this.numOfMines = this.width * this.height - 1;
    }
    int nextRow, nextCol;
    int i = 0;
    while (i < this.numOfMines) {
      nextRow = Math.round((float) Math.random() * (this.height - 1));
      nextCol = Math.round((float) Math.random() * (this.width - 1));
      if (!this.tiles[nextRow][nextCol].isMine()) {
        this.tiles[nextRow][nextCol].setMine();
        i += 1;
      }
    }
    this.setTileValues();
  }

  private void setTileValues() {
    for (int i = 0; i < this.height; i += 1) {
      for (int j = 0; j < this.width; j += 1) {
        if (this.tiles[i][j].isMine()) {
          continue;
        }
        int mines = 0;
        for (int k = i - 1; k <= i + 1; k += 1) {
          for (int l = j - 1; l <= j + 1; l += 1) {
            if (!(k < 0 || l < 0 || k >= this.height || l >= this.width)
                && !(k == i && l == j)
                && this.tiles[k][l].isMine()) {
              mines += 1;
            }
          }
        }
        this.tiles[i][j].setValue(mines);
      }
    }
    if (this.main.getStorage().isCreepy()) {
      this.addDuds();
    }
  }

  private void addDuds() {
    for (int i = 0; i < this.height; i += 1) {
      for (int j = 0; j < this.width; j += 1) {
        if (this.tiles[i][j].isMine() && Math.round((float) Math.random() * 5) == 0) {
          this.tiles[i][j].setDud();
        }
      }
    }
  }

  public Board(Minesweeper main) {
    this.main = main;
    setBackground(new Color(192, 192, 192));
    setBorder(
        BorderFactory.createCompoundBorder(
            BorderFactory.createEmptyBorder(5, 5, 5, 5),
            new ButtonBorder(
                Color.white, Color.white, new Color(128, 128, 128), new Color(128, 128, 128))));
  }

  public Minesweeper getMain() {
    return this.main;
  }

  public int getMines() {
    return this.numOfMines;
  }

  public void setBoard(int width, int height, int mines) {
    setVisible(false);
    this.height = height;
    this.width = width;
    this.numOfMines = mines;
    setLayout(new GridLayout(this.height, this.width, 0, 0));
    removeAll();
    this.tiles = new Tile[this.height][this.width];
    for (int i = 0; i < this.height; i += 1) {
      for (int j = 0; j < this.width; j += 1) {
        add(this.tiles[i][j] = new Tile(i, j, this));
      }
    }
    this.addMines();
    setVisible(true);
  }

  public void expand(int row, int col) {
    setVisible(false);
    for (int i = row - 1; i <= row + 1; i += 1) {
      for (int j = col - 1; j <= col + 1; j += 1) {
        if (!(i < 0 || j < 0 || i >= this.height || j >= this.width) && !(i == row && j == col)) {
          Tile tile = this.tiles[i][j];
          if (!tile.isUncovered() && !tile.isFlagged() && !tile.isUnsure() && !tile.isDud()) {
            tile.uncover(true);
          }
        }
      }
    }
    setVisible(true);
  }

  public void showMines() {
    setVisible(false);
    for (int i = 0; i < this.height; i += 1) {
      for (int j = 0; j < this.width; j += 1) {
        Tile tile = this.tiles[i][j];
        if (tile.isMine()
            && !tile.isUncovered()
            && !tile.isFlagged()
            && !tile.isUnsure()
            && !tile.isDud()) {
          tile.setTileIcon("covered mine");
        } else if ((!tile.isMine() || tile.isDud()) && tile.isFlagged()) {
          tile.setTileIcon("misflagged");
        }
      }
    }
    setVisible(true);
  }

  public void showFlags() {
    setVisible(false);
    for (int i = 0; i < this.height; i += 1) {
      for (int j = 0; j < this.width; j += 1) {
        Tile tile = this.tiles[i][j];
        if (tile.isMine() && !tile.isUncovered() && !tile.isFlagged()) {
          tile.setTileIcon("flagged");
        }
      }
    }
    setVisible(true);
  }

  public void removeAllMouseListeners() {
    for (int i = 0; i < this.height; i += 1) {
      for (int j = 0; j < this.width; j += 1) {
        this.tiles[i][j].removeMouseListener(this.tiles[i][j]);
      }
    }
  }

  public void checkWon(boolean expanding) {
    for (int i = 0; i < this.height; i += 1) {
      for (int j = 0; j < this.width; j += 1) {
        Tile tile = this.tiles[i][j];
        if ((tile.isFlagged() && !tile.isMine())
            || (!tile.isUncovered() && !tile.isFlagged() && !tile.isMine())) {
          return;
        }
      }
    }
    this.main.complete(expanding);
  }
}
