import java.awt.*;
import javax.swing.*;
import javax.swing.BorderFactory;
import javax.swing.plaf.basic.BasicBorders.ButtonBorder;

public class CounterDisplay extends JPanel {
  private static final long serialVersionUID = 8590228173889847000L;

  private Board board;

  private Digit hundred;
  private Digit tenth;
  private Digit first;

  private int mines;

  public CounterDisplay(Board board) {
    this.board = board;
    this.hundred = new Digit(this.board);
    this.tenth = new Digit(this.board);
    this.first = new Digit(this.board);
    this.mines = this.board.getMines();
    this.updateDisplay();
    setBackground(new Color(192, 192, 192));
    setBorder(
        BorderFactory.createCompoundBorder(
            BorderFactory.createEmptyBorder(5, 5, 5, 5),
            new ButtonBorder(
                Color.white, Color.white, new Color(128, 128, 128), new Color(128, 128, 128))));
    setVisible(false);
    setLayout(new GridLayout(1, 3, 0, 0));
    removeAll();
    add(this.hundred);
    add(this.tenth);
    add(this.first);
    setVisible(true);
  }

  public void increase() {
    this.mines += 1;
    this.updateDisplay();
  }

  public void decrease() {
    this.mines -= 1;
    if (this.mines < 0) {
      this.negativeLoop();
    } else {
      this.updateDisplay();
    }
  }

  public void reset() {
    this.mines = this.board.getMines();
    this.updateDisplay();
  }

  public void clear() {
    this.mines = 0;
    this.updateDisplay();
  }

  public void updateDisplay() {
    this.hundred.setDigitIcon(String.valueOf(mines / 100));
    this.tenth.setDigitIcon(String.valueOf(mines / 10 % 10));
    this.first.setDigitIcon(String.valueOf(mines % 10));
  }

  public void negativeLoop() {
    this.hundred.setDigitIcon("-");
    int temp = Math.abs(mines) % 100;
    this.tenth.setDigitIcon(String.valueOf(temp / 10 % 10));
    this.first.setDigitIcon(String.valueOf(temp % 10));
  }
}
