import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.BorderFactory;

public class CustomDialog extends JDialog implements ActionListener, WindowListener {
  private static final long serialVersionUID = 3593586540539735229L;

  private Minesweeper main;

  private JTextField height = new JTextField(5);
  private JTextField width = new JTextField(5);
  private JTextField mines = new JTextField(5);

  private int hValue;
  private int wValue;
  private int mValue;

  public CustomDialog(Minesweeper main) {
    super(main, "Custom Field", true);
    this.main = main;
    JPanel panel = new JPanel();
    Storage data = this.main.getStorage();
    this.hValue = data.getHeight();
    this.wValue = data.getWidth();
    this.mValue = data.getMines();
    this.height.setText(String.valueOf(this.hValue));
    this.width.setText(String.valueOf(this.wValue));
    this.mines.setText(String.valueOf(this.mValue));
    panel.setBorder(BorderFactory.createEmptyBorder(30, 10, 30, 10));
    add(panel);
    panel.setLayout(new GridBagLayout());
    GridBagConstraints c =
        new GridBagConstraints(
            3,
            3,
            1,
            1,
            0.0,
            1.0,
            GridBagConstraints.CENTER,
            GridBagConstraints.NONE,
            new Insets(2, 10, 2, 10),
            0,
            0);
    c.gridx = 3;
    c.fill = GridBagConstraints.HORIZONTAL;
    c.gridy = 0;
    JButton ok = new JButton("OK");
    panel.add(ok, c);
    this.getRootPane().setDefaultButton(ok);
    ok.addActionListener(this);
    c.gridx = 3;
    c.gridy = 2;
    JButton cancel = new JButton("Cancel");
    panel.add(cancel, c);
    cancel.addActionListener(this);
    c.gridx = 0;
    c.anchor = GridBagConstraints.EAST;
    c.gridy = 0;
    panel.add(new JLabel("Height:"), c);
    c.gridy = 1;
    panel.add(new JLabel("Width:"), c);
    c.gridy = 2;
    panel.add(new JLabel("Mines:"), c);
    c.gridx = 1;
    c.gridy = GridBagConstraints.RELATIVE;
    c.weightx = 1.0;
    c.fill = GridBagConstraints.HORIZONTAL;
    c.anchor = GridBagConstraints.CENTER;
    c.gridy = 0;
    panel.add(height, c);
    c.gridy = 1;
    panel.add(width, c);
    c.gridy = 2;
    panel.add(mines, c);
    pack();
    setResizable(false);
    Rectangle screenSize = getGraphicsConfiguration().getBounds();
    setLocation(
        screenSize.x + screenSize.width / 2 - getSize().width / 2,
        screenSize.y + screenSize.height / 2 - getSize().height / 2);
    setVisible(true);
  }

  public boolean setValues() {
    try {
      this.wValue = Integer.decode(width.getText()).intValue();
      if (this.wValue < 9) {
        this.wValue = 9;
      } else if (this.wValue > 30) {
        this.wValue = 30;
      }
      this.hValue = Integer.decode(height.getText()).intValue();
      if (this.hValue < 9) {
        this.hValue = 9;
      } else if (this.hValue > 24) {
        this.hValue = 24;
      }
      this.mValue = Integer.decode(mines.getText()).intValue();
      if (this.mValue < 10) {
        this.mValue = 10;
      } else if (this.mValue > 668) {
        this.mValue = 668;
      }
    } catch (NumberFormatException e) {
      return false;
    }
    return true;
  }

  public int getHeightValue() {
    return this.hValue;
  }

  public int getWidthValue() {
    return this.wValue;
  }

  public int getMinesValue() {
    return this.mValue;
  }

  @Override
  public void actionPerformed(ActionEvent e) {
    String cmd = e.getActionCommand();
    if (cmd.equals("Cancel") || this.setValues()) {
      this.dispose();
    }
  }

  @Override
  public void windowClosing(WindowEvent e) {
    this.dispose();
  }

  @Override
  public void windowOpened(WindowEvent e) {}

  @Override
  public void windowClosed(WindowEvent e) {}

  @Override
  public void windowIconified(WindowEvent e) {}

  @Override
  public void windowDeiconified(WindowEvent e) {}

  @Override
  public void windowActivated(WindowEvent e) {}

  @Override
  public void windowDeactivated(WindowEvent e) {}
}
