import java.awt.event.*;
import javax.swing.*;

public class Menubar extends JMenuBar implements ActionListener {
  private static final long serialVersionUID = 865388774192274414L;

  private Minesweeper main;

  private JCheckBoxMenuItem creepy;
  private JCheckBoxMenuItem sound;

  public Menubar(Minesweeper main) {
    this.main = main;
    JMenu game = new JMenu("Game");
    add(game);
    JMenuItem newGame = new JMenuItem("New");
    game.add(newGame);
    newGame.addActionListener(this);
    game.addSeparator();
    Storage data = this.main.getStorage();
    JRadioButtonMenuItem beginner =
        new JRadioButtonMenuItem(
            "Beginner", (data.getDifficulty() == this.main.BEGINNER) ? true : false);
    JRadioButtonMenuItem intermediate =
        new JRadioButtonMenuItem(
            "Intermediate", (data.getDifficulty() == this.main.INTERMEDIATE) ? true : false);
    JRadioButtonMenuItem expert =
        new JRadioButtonMenuItem(
            "Expert", (data.getDifficulty() == this.main.EXPERT) ? true : false);
    JRadioButtonMenuItem custom =
        new JRadioButtonMenuItem(
            "Custom...", (data.getDifficulty() == this.main.CUSTOM) ? true : false);
    this.creepy = new JCheckBoxMenuItem("Creepy Mode", (data.isCreepy()) ? true : false);
    game.add(beginner);
    game.add(intermediate);
    game.add(expert);
    game.add(custom);
    game.add(creepy);
    ButtonGroup difficulties = new ButtonGroup();
    difficulties.add(beginner);
    difficulties.add(intermediate);
    difficulties.add(expert);
    difficulties.add(custom);
    beginner.addActionListener(this);
    intermediate.addActionListener(this);
    expert.addActionListener(this);
    custom.addActionListener(this);
    custom.setActionCommand("Custom");
    creepy.addActionListener(this);
    game.addSeparator();
    this.sound = new JCheckBoxMenuItem("Sound", (data.isSoundEnabled()) ? true : false);
    game.add(sound);
    sound.addActionListener(this);
    game.addSeparator();
    JMenuItem bestTimes = new JMenuItem("Best Times...");
    game.add(bestTimes);
    bestTimes.addActionListener(this);
    bestTimes.setActionCommand("Best Times");
    game.addSeparator();
    JMenuItem exit = new JMenuItem("Exit");
    game.add(exit);
    exit.addActionListener(this);
  }

  @Override
  public void actionPerformed(ActionEvent e) {
    String cmd = e.getActionCommand();
    if (cmd.equals("New")) {
      this.main.newGame();
    } else {
      Storage data = this.main.getStorage();
      if (cmd.equals("Beginner")) {
        data.setDifficulty(this.main.BEGINNER);
        this.main.newGame();
      } else if (cmd.equals("Intermediate")) {
        data.setDifficulty(this.main.INTERMEDIATE);
        this.main.newGame();
      } else if (cmd.equals("Expert")) {
        data.setDifficulty(this.main.EXPERT);
        this.main.newGame();
      } else if (cmd.equals("Custom")) {
        CustomDialog dialog = new CustomDialog(this.main);
        data.setDifficulty(this.main.CUSTOM);
        data.setHeight(dialog.getHeightValue());
        data.setWidth(dialog.getWidthValue());
        data.setMines(dialog.getMinesValue());
        this.main.newGame();
      } else if (cmd.equals("Creepy Mode")) {
        data.switchCreepy();
        if (!data.isSoundEnabled()) {
          data.switchSound();
          this.sound.setSelected(true);
        }
        if (this.main.isGameStarted()) {
          this.main.newGame();
        }
      } else if (cmd.equals("Sound")) {
        data.switchSound();
        if (data.isCreepy()) {
          data.switchCreepy();
          this.creepy.setSelected(false);
          this.main.newGame();
        } else if (this.main.isGameStarted()) {
          PlaySound play = this.main.getPlay();
          if (play.isPlaying()) {
            play.stop();
          } else {
            play.tick();
          }
        }
      } else if (cmd.equals("Best Times")) {
        new BestTimesDialog(this.main);
      } else if (cmd.equals("Exit")) {
        System.exit(0);
      }
    }
  }
}
