import java.awt.*;
import javax.swing.*;

public class Minesweeper extends JFrame {
  private static final long serialVersionUID = -711696178703199107L;

  private Board board;
  private Info info;
  private PlaySound play;
  private Resource images;
  private Storage data;

  private boolean gameStarted;

  private final String RES_GAME_ICON = "icon.png";

  public final int BEGINNER = 0;
  public final int INTERMEDIATE = 1;
  public final int EXPERT = 2;
  public final int CUSTOM = 3;

  private void setLocationCenter() {
    Rectangle screen = getGraphicsConfiguration().getBounds();
    setLocation(
        screen.x + screen.width / 2 - getSize().width / 2,
        screen.y + screen.height / 2 - getSize().height / 2);
  }

  public Minesweeper() {
    super("Minesweeper");
    this.data = new Storage();
    this.images = new Resource();
    setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
    setIconImage(Toolkit.getDefaultToolkit().getImage(getClass().getResource(RES_GAME_ICON)));
    setJMenuBar(new Menubar(this));
    setLayout(new BorderLayout());
    this.data = new Storage();
    this.board = new Board(this);
    this.board.setBoard(
        this.data.getWidth(),
        this.data.getHeight(),
        this.data.getMines()); // must call setBoard before create instances of Info
    this.info = new Info(this);
    this.play = new PlaySound();
    this.gameStarted = false;
    add(this.info, "North");
    add(this.board);
    pack();
    setResizable(false);
    this.setLocationCenter();
    setVisible(true);
  }

  public void newGame() {
    this.board.setBoard(this.data.getWidth(), this.data.getHeight(), this.data.getMines());
    pack();
    if (this.isGameStarted()) {
      this.info.getTimer().stop();
      if (this.data.isSoundEnabled()) {
        this.play.stop();
      }
    }
    this.info.getCounter().reset();
    this.info.getSmiley().setSmileyIcon("smile");
    this.info.getTimer().reset();
    this.stopGame();
  }

  public void delGame() {
    this.stopGame();
    if (this.data.isSoundEnabled()) {
      this.play.stop();
      this.play.boom();
    }
    this.info.getTimer().stop();
    this.info.getSmiley().setSmileyIcon("death");
    this.board.removeAllMouseListeners();
    this.board.showMines();
  }

  public Board getBoard() {
    return this.board;
  }

  public Info getInfo() {
    return this.info;
  }

  public PlaySound getPlay() {
    return this.play;
  }

  public Resource getImage() {
    return this.images;
  }

  public Storage getStorage() {
    return this.data;
  }

  public boolean isGameStarted() {
    return this.gameStarted;
  }

  public void startGame() {
    this.gameStarted = true;
  }

  public void stopGame() {
    this.gameStarted = false;
  }

  public void complete(boolean expanding) {
    this.stopGame();
    this.info.getTimer().stop();
    this.info.getSmiley().setSmileyIcon("boss");
    this.board.removeAllMouseListeners();
    this.board.showFlags();
    this.info.getCounter().clear();
    if (this.data.isSoundEnabled() && !this.data.isCreepy() && !expanding) {
      this.play.stop();
      this.play.win();
    }
    if (this.isNewRecord() && !this.data.isCreepy()) {
      new NewRecordDialog(this);
    }
  }

  public boolean isNewRecord() {
    int seconds = this.info.getTimer().getTime();
    switch (this.data.getDifficulty()) {
      case 0:
        if (seconds < this.data.getRecord(this.BEGINNER)) {
          return true;
        }
        break;
      case 1:
        if (seconds < this.data.getRecord(this.INTERMEDIATE)) {
          return true;
        }
        break;
      case 2:
        if (seconds < this.data.getRecord(this.EXPERT)) {
          return true;
        }
        break;
      default:
    }
    return false;
  }
}
