import java.io.*;

public class Storage {
  private int difficulty;
  private int height;
  private int width;
  private int mines;
  private boolean creepy;
  private boolean soundEnabled;
  private int[] records;
  private String[] names;

  private final int NUM_OF_DIFFICULTIES = 3;
  private final String DATA_FILE = "Minesweeper.dat";

  private void open(final String filename) throws FileNotFoundException, IOException {
    DataInputStream in = new DataInputStream(new FileInputStream(filename));
    this.difficulty = in.readInt();
    this.height = in.readInt();
    this.width = in.readInt();
    this.mines = in.readInt();
    this.creepy = in.readBoolean();
    this.soundEnabled = in.readBoolean();
    for (int i = 0; i < NUM_OF_DIFFICULTIES; i += 1) {
      this.records[i] = in.readInt();
      this.names[i] = in.readUTF();
    }
    in.close();
  }

  public Storage() {
    this.records = new int[this.NUM_OF_DIFFICULTIES];
    this.names = new String[this.NUM_OF_DIFFICULTIES];
    try {
      this.open(this.DATA_FILE);
    } catch (Exception e) {
      this.difficulty = 0;
      this.height = 9;
      this.width = 9;
      this.mines = 10;
      this.creepy = false;
      this.soundEnabled = false;
      this.records = new int[] {999, 999, 999};
      this.names = new String[] {"Anonymous", "Anonymous", "Anonymous"};
      try {
        this.save(this.DATA_FILE);
      } catch (Exception v) {
      }
    }
  }

  public void save(final String filename) throws FileNotFoundException, IOException {
    DataOutputStream out = new DataOutputStream(new FileOutputStream(filename));
    out.writeInt(this.difficulty);
    out.writeInt(this.height);
    out.writeInt(this.width);
    out.writeInt(this.mines);
    out.writeBoolean(this.creepy);
    out.writeBoolean(this.soundEnabled);
    for (int i = 0; i < NUM_OF_DIFFICULTIES; i += 1) {
      out.writeInt(this.records[i]);
      out.writeUTF(this.names[i]);
    }
    out.close();
  }

  public int getDifficulty() {
    return this.difficulty;
  }

  public int getHeight() {
    return this.height;
  }

  public int getWidth() {
    return this.width;
  }

  public int getMines() {
    return this.mines;
  }

  public boolean isCreepy() {
    return this.creepy;
  }

  public boolean isSoundEnabled() {
    return this.soundEnabled;
  }

  public int getRecord(int difficulty) {
    return this.records[difficulty];
  }

  public String getName(int difficulty) {
    return this.names[difficulty];
  }

  public void setDifficulty(int difficulty) {
    this.difficulty = difficulty;
    switch (difficulty) {
      case 0:
        this.height = 9;
        this.width = 9;
        this.mines = 10;
        break;
      case 1:
        this.height = 16;
        this.width = 16;
        this.mines = 40;
        break;
      case 2:
        this.height = 16;
        this.width = 30;
        this.mines = 99;
    }
    try {
      this.save(this.DATA_FILE);
    } catch (Exception e) {
    }
  }

  public void setHeight(int height) {
    this.height = height;
    try {
      this.save(this.DATA_FILE);
    } catch (Exception e) {
    }
  }

  public void setWidth(int width) {
    this.width = width;
    try {
      this.save(this.DATA_FILE);
    } catch (Exception e) {
    }
  }

  public void setMines(int mines) {
    this.mines = mines;
    try {
      this.save(this.DATA_FILE);
    } catch (Exception e) {
    }
  }

  public void switchCreepy() {
    this.creepy = !this.creepy;
    try {
      this.save(this.DATA_FILE);
    } catch (Exception e) {
    }
  }

  public void switchSound() {
    this.soundEnabled = !this.soundEnabled;
    try {
      this.save(this.DATA_FILE);
    } catch (Exception e) {
    }
  }

  public void setRecord(int difficulty, int score) {
    this.records[difficulty] = score;
    try {
      this.save(this.DATA_FILE);
    } catch (Exception e) {
    }
  }

  public void setName(int difficulty, String name) {
    this.names[difficulty] = name;
    try {
      this.save(this.DATA_FILE);
    } catch (Exception e) {
    }
  }
}
