import java.awt.*;
import java.util.Timer;
import java.util.TimerTask;
import javax.swing.*;
import javax.swing.BorderFactory;
import javax.swing.plaf.basic.BasicBorders.ButtonBorder;

public class TimerDisplay extends JPanel {
  private static final long serialVersionUID = -1661506846325986431L;

  private Board board;
  private Timer timer;

  private Digit hundred;
  private Digit tenth;
  private Digit first;

  private int seconds;
  private boolean stopped;

  public TimerDisplay(Board board) {
    this.board = board;
    this.hundred = new Digit(this.board);
    this.tenth = new Digit(this.board);
    this.first = new Digit(this.board);
    setBackground(new Color(192, 192, 192));
    setBorder(
        BorderFactory.createCompoundBorder(
            BorderFactory.createEmptyBorder(5, 5, 5, 5),
            new ButtonBorder(
                Color.white, Color.white, new Color(128, 128, 128), new Color(128, 128, 128))));
    setVisible(false);
    setLayout(new GridLayout(1, 3, 0, 0));
    removeAll();
    add(this.hundred);
    add(this.tenth);
    add(this.first);
    setVisible(true);
  }

  public int getTime() {
    return this.seconds;
  }

  public void start() {
    this.stopped = false;
    this.timer = new Timer();
    TimerTask tt =
        new TimerTask() {
          @Override
          public void run() {
            increase();
          }
        };
    this.timer.scheduleAtFixedRate(tt, 0, 1000);
  }

  public void stop() {
    if (!this.stopped) {
      this.timer.cancel();
      this.stopped = true;
    }
  }

  public void increase() {
    this.seconds += 1;
    if (this.seconds >= 999) {
      this.stop();
    }
    this.updateDisplay();
  }

  public void reset() {
    this.seconds = 0;
    this.updateDisplay();
  }

  public void updateDisplay() {
    this.hundred.setDigitIcon(String.valueOf(seconds / 100));
    this.tenth.setDigitIcon(String.valueOf(seconds / 10 % 10));
    this.first.setDigitIcon(String.valueOf(seconds % 10));
  }
}
